@@ -1,11 +1,24 @@
 package Statocles::Plugin::LinkCheck;
-our $VERSION = '0.095';
+our $VERSION = '0.096';
 # ABSTRACT: Check links and images for validity during build
 
 use Statocles::Base 'Class';
 with 'Statocles::Plugin';
 use Mojo::Util qw( url_escape url_unescape );
 
+#pod =attr fatal
+#pod
+#pod If set to true, and there are any broken links, the plugin will also call
+#pod C<die()> after printing the problems. Defaults to false.
+#pod
+#pod =cut
+
+has fatal => (
+    is => 'ro',
+    isa => Bool,
+    default => 0,
+);
+
 #pod =attr ignore
 #pod
 #pod An array of URL patterns to ignore. These are interpreted as regular expressions,
@@ -95,6 +108,8 @@ sub check_pages {
                     ;
             $event->emitter->log->warn( "URL broken on $m->[1]: $msg" );
         }
+
+        die 'Link check failed!' if $self->fatal;
     }
 }
 
@@ -123,7 +138,7 @@ Statocles::Plugin::LinkCheck - Check links and images for validity during build
 
 =head1 VERSION
 
-version 0.095
+version 0.096
 
 =head1 SYNOPSIS
 
@@ -138,10 +153,16 @@ version 0.095
 =head1 DESCRIPTION
 
 This plugin checks all of the links and images to ensure they exist. If something
-is missing, this plugin will write a warning to the screen.
+is missing, this plugin will write a warning to the screen. If fatal is set to true,
+it will also call C<die()> afterwards.
 
 =head1 ATTRIBUTES
 
+=head2 fatal
+
+If set to true, and there are any broken links, the plugin will also call
+C<die()> after printing the problems. Defaults to false.
+
 =head2 ignore
 
 An array of URL patterns to ignore. These are interpreted as regular expressions,
